@@ -1,15 +1,21 @@
-# flake8: noqa E501
+"""Sphinx configuration for vcspull documentation."""
+
+# flake8: noqa: E501
+from __future__ import annotations
+
 import inspect
-import os
+import pathlib
 import sys
 import typing as t
-from os.path import dirname, relpath
-from pathlib import Path
+from os.path import relpath
 
 import vcspull
 
+if t.TYPE_CHECKING:
+    from sphinx.application import Sphinx
+
 # Get the project root dir, which is the parent dir of this
-cwd = Path.cwd()
+cwd = pathlib.Path.cwd()
 project_root = cwd.parent
 src_root = project_root / "src"
 
@@ -18,7 +24,7 @@ sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
 about: dict[str, str] = {}
-with open(src_root / "vcspull" / "__about__.py") as fp:
+with (src_root / "vcspull" / "__about__.py").open() as fp:
     exec(fp.read(), about)
 
 extensions = [
@@ -41,6 +47,7 @@ myst_enable_extensions = [
     "substitution",
     "replacements",
     "strikethrough",
+    "linkify",
 ]
 
 templates_path = ["_templates"]
@@ -50,10 +57,10 @@ source_suffix = {".rst": "restructuredtext", ".md": "markdown"}
 master_doc = "index"
 
 project = about["__title__"]
-copyright = about["__copyright__"]
+project_copyright = about["__copyright__"]
 
-version = "%s" % (".".join(about["__version__"].split("."))[:2])
-release = "%s" % (about["__version__"])
+version = "{}".format(".".join(about["__version__"].split("."))[:2])
+release = "{}".format(about["__version__"])
 
 exclude_patterns = ["_build"]
 
@@ -93,7 +100,7 @@ html_sidebars = {
         "sidebar/navigation.html",
         "sidebar/projects.html",
         "sidebar/scroll-end.html",
-    ]
+    ],
 }
 
 # linkify_issues
@@ -133,54 +140,17 @@ rediraffe_branch = "master~1"
 # sphinxext.opengraph
 ogp_site_url = about["__docs__"]
 ogp_image = "_static/img/icons/icon-192x192.png"
-ogp_desscription_length = about["__description__"]
 ogp_site_name = about["__title__"]
 
-htmlhelp_basename = "%sdoc" % about["__title__"]
-
-latex_documents = [
-    (
-        "index",
-        "{}.tex".format(about["__package_name__"]),
-        "{} Documentation".format(about["__title__"]),
-        about["__author__"],
-        "manual",
-    )
-]
-
-man_pages = [
-    (
-        "index",
-        about["__package_name__"],
-        "{} Documentation".format(about["__title__"]),
-        about["__author__"],
-        1,
-    )
-]
-
-texinfo_documents = [
-    (
-        "index",
-        "{}".format(about["__package_name__"]),
-        "{} Documentation".format(about["__title__"]),
-        about["__author__"],
-        about["__package_name__"],
-        about["__description__"],
-        "Miscellaneous",
-    )
-]
-
 intersphinx_mapping = {
     "py": ("https://docs.python.org/", None),
     "libvcs": ("http://libvcs.git-pull.com/", None),
 }
 
 
-def linkcode_resolve(
-    domain: str, info: dict[str, str]
-) -> t.Union[None, str]:  # NOQA: C901
+def linkcode_resolve(domain: str, info: dict[str, str]) -> None | str:
     """
-    Determine the URL corresponding to Python object
+    Determine the URL corresponding to Python object.
 
     Notes
     -----
@@ -201,7 +171,7 @@ def linkcode_resolve(
     for part in fullname.split("."):
         try:
             obj = getattr(obj, part)
-        except Exception:
+        except Exception:  # noqa: PERF203
             return None
 
     # strip decorators, which would resolve to the source of the decorator
@@ -226,12 +196,9 @@ def linkcode_resolve(
     except Exception:
         lineno = None
 
-    if lineno:
-        linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1)
-    else:
-        linespec = ""
+    linespec = f"#L{lineno}-L{lineno + len(source) - 1}" if lineno else ""
 
-    fn = relpath(fn, start=dirname(vcspull.__file__))
+    fn = relpath(fn, start=pathlib.Path(vcspull.__file__).parent)
 
     if "dev" in about["__version__"]:
         return "{}/blob/master/{}/{}/{}{}".format(
@@ -241,12 +208,23 @@ def linkcode_resolve(
             fn,
             linespec,
         )
-    else:
-        return "{}/blob/v{}/{}/{}/{}{}".format(
-            about["__github__"],
-            about["__version__"],
-            "src",
-            about["__package_name__"],
-            fn,
-            linespec,
-        )
+    return "{}/blob/v{}/{}/{}/{}{}".format(
+        about["__github__"],
+        about["__version__"],
+        "src",
+        about["__package_name__"],
+        fn,
+        linespec,
+    )
+
+
+def remove_tabs_js(app: Sphinx, exc: Exception) -> None:
+    """Fix for sphinx-inline-tabs#18."""
+    if app.builder.format == "html" and not exc:
+        tabs_js = pathlib.Path(app.builder.outdir) / "_static" / "tabs.js"
+        tabs_js.unlink(missing_ok=True)
+
+
+def setup(app: Sphinx) -> None:
+    """Sphinx setup hook."""
+    app.connect("build-finished", remove_tabs_js)
