@@ -1,7 +1,11 @@
+"""Metadata for vcspull."""
+
+from __future__ import annotations
+
 __title__ = "vcspull"
 __package_name__ = "vcspull"
-__description__ = "Manage and sync multiple git, mercurial, and svn repos"
-__version__ = "1.17.1"
+__description__ = "Repo manager and syncer for git, mercurial, and svn"
+__version__ = "1.39.1"
 __author__ = "Tony Narlock"
 __github__ = "https://github.com/vcs-python/vcspull"
 __docs__ = "https://vcspull.git-pull.com"
